package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.component.ImageFileUtils;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.mapper.RmsCarrierMapper;
import com.steerinfo.dil.service.impl.RmsBidAreaServiceImpl;
import com.steerinfo.dil.service.impl.RmsCarrierServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import com.steerinfo.framework.utils.misc.IdGenerator;
import com.steerinfo.framework.utils.upload.UploadUtils;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.math.BigDecimal;
import java.text.ParseException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * RmsCarrier RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-11-18 08:46
 * 类描述
 * 修订历史：
 * 日期：2021-11-18
 * 作者：generator
 * 参考：
 * 描述：RmsCarrier RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
    @RequestMapping("/${api.version}/rmscarrier")
public class RmsCarrierController extends BaseRESTfulController {

    @Autowired
    RmsCarrierServiceImpl rmsCarrierService;
    @Autowired
    RmsBidAreaServiceImpl rmsBidAreaService;

    @Autowired
    ColumnDataUtil columnDataUtil;

    @Autowired
    ESFeign esFeign;

    @Autowired
    private ImageFileUtils imageFileUtils;

    /**
     * 展示承运商信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @return
     */
    @ApiOperation(value = "获取列表", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "342", required = false, dataType = "BigDecimal"),
    })
    //@RequiresPermissions("rmscarrier:view")
    @PostMapping(value = "/getCarrierList")
    public RESTfulResult getCarrierList(@RequestBody(required = false) Map<String, Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize,
                                        String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        if (con != null && (con.equals("") || con.equals("undefined")) ) {
            con = null;
        }
        if (con != null && con.length() != 0) {
            mapValue.put("con","%" + con + "%");
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = rmsCarrierService.getCarrierList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsCarrierService.getCarrierList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }

    /**
     * 添加承运商信息
     *
     * @param
     * @return
     */
    @ApiOperation(value = "创建", notes = "根据RmsCarrier对象创建")
    @ApiImplicitParam(name = "rmsCarrier", value = "详细实体rmsCarrier", required = true, dataType = "RmsCarrier")
    @PostMapping(value = "/insertCarrier")
    public RESTfulResult insertCarrier(@RequestBody(required = false) Map<String, Object> mapValue) throws ParseException {
        int result = rmsCarrierService.insertCarrier(mapValue);
        if (result == 0) {
            return failed();
        }
        return success(result);
    }

    /**
     * 更改承运商信息
     *
     * @param mapValue
     * @return
     */
    @ApiOperation(value = "更新详细信息", notes = "根据url的id来指定更新对象，并根据传过来的rmsCarrier信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "rmsCarrier", value = "详细实体rmsCarrier", required = true, dataType = "RmsCarrier")
    })
    //@RequiresPermissions("rmscarrier:update")
    @PostMapping(value = "/updateCarrier", produces = "application/json;charset=UTF-8")
    public RESTfulResult updateCarrier(@RequestBody(required = false) Map<String, Object> mapValue) throws ParseException {
        int result = rmsCarrierService.updateCarrier(mapValue);
        return success(result);
    }

    /**
     * 删除承运商信息
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "删除", notes = "根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    //@RequiresPermissions("rmscarrier:delete")
    @PostMapping(value = "/deleteCarrier/{id}")//BigDecimal
    public RESTfulResult deleteCarrier(@PathVariable("id") BigDecimal id) {

        return success(rmsCarrierService.deleteCarrier(id));
    }

    /**
     * 根据id值详细获取承运商信息
     */
    @ApiOperation(value = "获取详细信息", notes = "根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getCarrierById/{id}")
    public RESTfulResult getCarrierById(@PathVariable("id") BigDecimal id) throws Exception {
        List<Map<String, Object>> list = rmsCarrierService.getCarrierById(id);
        for (Map<String, Object> map : list) {
            String carrierTransportType = (String) map.get("carrierTransportType");
            if (carrierTransportType != null) {
                if (carrierTransportType.equals("危化品")) {
                    map.put("carrierTransportType", 1);
                }
                if (carrierTransportType.equals("其他")) {
                    map.put("carrierTransportType", 2);
                }
            }
            //通过路径获得base64编码
            //许可证
            if (map.containsKey("carrierBusinessAblelicense")&&map.get("carrierBusinessAblelicense")!=null){
                String carrierBusinessAblelicense = imageFileUtils.downloadFile(map.get("carrierBusinessAblelicense").toString()).toString();
                if (carrierBusinessAblelicense!=null){
                    map.put("carrierBusinessAblelicense",carrierBusinessAblelicense);
                }
            }

            //证明书
            if (map.containsKey("carrierTransportCertificate")&&map.get("carrierTransportCertificate")!=null){
                String carrierTransportCertificate = imageFileUtils.downloadFile(map.get("carrierTransportCertificate").toString()).toString();
                if (carrierTransportCertificate!=null){
                    map.put("carrierTransportCertificate",carrierTransportCertificate);
                }
            }
            //许可证
            if (map.containsKey("carrierBusinessLicense")&&map.get("carrierBusinessLicense")!=null){
                String carrierBusinessLicense = imageFileUtils.downloadFile(map.get("carrierBusinessLicense").toString()).toString();
                if (carrierBusinessLicense!=null){
                    map.put("carrierBusinessLicense",carrierBusinessLicense);
                }
            }
        }
        return success(list);
    }

    /**
     * 根据id获取中标区域
     */
    @ApiOperation(value = "展示中标区域信息", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "406", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "id", value = "中标id", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getCarrierBidAreaList")
    public RESTfulResult getCarrierBidAreaList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_bidareas_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsCarrierService.getCarrierBidAreaList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_bidareas_list");
            //添加id
            map.put("indexId", "bidAreasId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsCarrierService.getCarrierBidAreaList(mapValue);
        }
        System.out.println(listTotal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsCarrierService.getCarrierBidAreaList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }

    //    处理承运商照片
    @PostMapping("/uploadCarrier1")
    public RESTfulResult uploadCarrier1(@RequestParam("file") MultipartFile multipartFile) throws Exception {
//        String str="运输证";
//        int result=rmsCarrierService.uploadCarrier(multipartFile,str);
//        if (result<1){
//            return failed();
//        }
//        return success(result);
        String url = imageFileUtils.updateFile(multipartFile);
        return success(url);
    }

    @PostMapping(value = "/getFile")
    @ResponseBody
    public String  getImgBytes(@RequestBody String url) throws Exception {
        String b = imageFileUtils.downloadFile(url).toString();
        return b;
    }
    //    处理承运商照片
    @PostMapping("/uploadCarrier2")
    public RESTfulResult uploadCarrier2(@RequestParam("file") MultipartFile multipartFile) {
        String str = "经营许可证";
        Integer result=rmsCarrierService.uploadCarrier(multipartFile,str);
        if (result<1){
            return failed();
        }
        return success(result);
    }
    //    处理承运商照片
    @PostMapping("/uploadCarrier3")
    public RESTfulResult uploadCarrier3(@RequestParam("file") MultipartFile  multipartFile) {
        String str = "营业执照";
        Integer result=rmsCarrierService.uploadCarrier(multipartFile,str);
        if (result<1){
        return failed();
        }
        return success(result);
    }
    //根据运力id查询承运商名称
    @PostMapping(value = "/getCarrierNameById/{id}")
    public RESTfulResult getCarrierNameById(@PathVariable("id") BigDecimal id){
        Map<String,Object> map = rmsCarrierService.getCarrierNameById(id);
        return success(map);
    }

}
